varying highp vec4 v_texWave;
varying mediump vec4 v_eyeDir;
varying mediump vec2 v_maskTexCoord;
varying mediump vec4 v_lightDir;

uniform sampler2D u_maskTexture;

vec3 decodeNormal(vec4 tex)
{
    mediump vec3 norm = tex.rgb * 2.0 - 1.0;
    return norm;
}

float saturate(float x)
{
    return clamp(x, 0.0, 1.0);
}

float FresnelSimple(float cosI)
{
    float facing = 1.0 - max(cosI, 0.0);
    return pow(facing, 4.0);
}

mediump float pow8(mediump float f)
{
    mediump float f2 = f * f;
    mediump float f4 = f2 * f2;
    return f4 * f4 * f4 * f4;
}

void main()
{
    // normal
    mediump vec4 texWave = v_texWave / v_lightDir.w;// vec4(v_lightDir.w, 1.0, v_lightDir.w, 1.0);
    lowp vec3 bump1 = texture2D(CC_Texture0, texWave.xy).rgb;
    lowp vec3 bump2 = texture2D(CC_Texture0, texWave.zw).rgb;
    mediump vec3 normal = (bump1 * 1.2 + bump2) - 1.0;
    normal = normalize(normal);
    lowp vec4 maskColor = texture2D(u_maskTexture, v_maskTexCoord.xy + normal.xy * 0.02);
    lowp vec4 maskColor2 = texture2D(u_maskTexture, v_maskTexCoord.xy);

    lowp float alpha = maskColor2.a;
    if (alpha < 0.006)
        discard;

    mediump vec3 eyeDir = v_eyeDir.xyz;
    mediump vec3 lightDir = v_lightDir.xyz;
    // specular
    mediump vec3 halfDir = normalize(eyeDir + lightDir);
    mediump float hdotn = dot(halfDir, normal);
    lowp float dt = hdotn > 0.95 ? pow(hdotn, 130.0) : 0.0;
    lowp vec3 specColor = vec3(dt);
    lowp vec3 waterColor = maskColor.rgb * v_eyeDir.w;
    lowp vec3 color = waterColor + specColor;
    color = mix(vec3(0.9, 0.9, 0.9), color, alpha * alpha * alpha);

    gl_FragColor = vec4(color, alpha);
}