varying highp vec4 v_texWave;
varying mediump vec4 v_eyeDir;
varying mediump vec2 v_maskTexCoord;
varying mediump vec4 v_texCaustic;

uniform sampler2D u_maskTexture;
uniform sampler2D u_causticTexture;
uniform mediump vec3 u_lightDir;

float saturate(float x)
{
    return clamp(x, 0.0, 1.0);
}

void main()
{
    vec4 maskColor = texture2D(u_maskTexture, v_maskTexCoord.xy);
    float alpha = smoothstep(0.95, 0.0, maskColor.r);
    if (alpha <= 0.0)
        discard;

    // normal
    lowp vec3 tx = texture2D(CC_Texture0, v_texWave.xy).rgb;
    lowp vec3 tx2 = texture2D(CC_Texture0, v_texWave.zw).rgb;

    lowp vec3 waterColor = vec3(0.01, 0.46, 0.77);
    lowp vec3 color = waterColor * v_eyeDir.w;

	lowp vec3 c = pow(tx * tx2 * 2.5, vec3(8.0));
	color += vec3(c.y);
	color += vec3(c.z);

    if (maskColor.r > 0.0)
    {
        float edgeFactor = maskColor.r;
        // Caustic
        lowp float caustic1 = texture2D( u_causticTexture, v_texCaustic.xy).r;
        lowp float caustic2 = texture2D( u_causticTexture, v_texCaustic.zw).r;
        float causticResult = caustic1 * caustic2;
        vec3 causticColor = causticResult * vec3(0.5, 1.0, 0.6) * pow(edgeFactor, 2.0) * 70.0;
        vec3 edgeColor = vec3(0.52, 1.0, 0.89);
        color = mix(color, edgeColor + causticColor, edgeFactor);
    }

    gl_FragColor = vec4(color, alpha);
}