attribute vec4 a_position;
attribute vec2 a_texCoord;

uniform mediump vec2 u_texOrigin;
uniform mediump vec4 u_maskTexCoord;

varying mediump vec4 v_texWave;
varying mediump vec4 v_eyeDir;
varying mediump vec2 v_maskTexCoord;
varying mediump vec4 v_lightDir;

void main(void)
{
    gl_Position = CC_PMatrix * a_position;
    vec3 eyePos = vec3(0.0, 16.5, 1.3);
    vec3 lightPos = vec3(-0.0, 0.5, 2.3);
    vec2 worldPos = gl_Position.xy / gl_Position.w;
    float y = (worldPos.y + 1.0) * 0.5;

    mediump vec2 texCoord = (a_texCoord.xy + u_texOrigin);
    v_lightDir.xyz = normalize(lightPos - vec3(texCoord * 0.1, 0.0));
    mediump vec4 waveScale = vec4(0.6, 1.4, 3.5, 7.0);
    highp vec4 waveSpeed = vec4(-0.01, 0.05, -0.08, -0.05);
    mediump vec4 waveOffset = fract(waveSpeed * CC_Time.y);
    v_texWave = texCoord.xyxy * waveScale + waveOffset;

    worldPos.y *= 960.0 / 640.0;
    v_eyeDir.xyz = normalize(eyePos - vec3(worldPos, 0.0));
    v_eyeDir.w = min(1.0, mix(0.8, 1.1, y));
    v_maskTexCoord = a_texCoord.xy * u_maskTexCoord.zw + u_maskTexCoord.xy;
    v_lightDir.w = mix(0.7, 1.2, v_maskTexCoord.y);

}

